@@ -17,7 +17,6 @@ our @EXPORT = qw(
     run_command
     run_perl_command
     do_foreach_env_combination
-    profile_this_code
 );
 
 use Devel::NYTProf::Data;
@@ -190,6 +189,9 @@ sub run_test_group {
         print "nytprofcvs: $nytprofcsv\n";
     }
 
+    plan skip_all => "No '$group.*' test files and no extra_test_code"
+        if !@tests and !$extra_test_code;
+
     my $tests_per_env = number_of_tests(@tests) + $extra_test_count + 1;
 
     plan tests => 1 + $tests_per_env * @env_combinations;
@@ -210,11 +212,14 @@ sub run_test_group {
 
         if ($extra_test_code) {
             print("running $extra_test_count extra tests...\n");
-            my $profile = eval { Devel::NYTProf::Data->new({ filename => $profile_datafile }) };
-            if ($@) {
-                diag($@);
-                fail("extra tests group '$group'") foreach (1 .. $extra_test_count);
-                return;
+            my $profile;
+            if (@tests) {
+                $profile = eval { Devel::NYTProf::Data->new({ filename => $profile_datafile }) };
+                if ($@) {
+                    diag($@);
+                    fail("extra tests group '$group'") foreach (1 .. $extra_test_count);
+                    return;
+                }
             }
 
             $extra_test_code->($profile, $env);
@@ -236,6 +241,7 @@ sub run_test {
         return;
     };
     my ($basename, $fork_seqn, $type) = ($1, $2 || 0, $3);
+    #warn "($basename, $fork_seqn, $type)\n";
 
     my $profile_datafile = $NYTPROF_TEST{file};
     my $test_datafile = (profile_datafiles($profile_datafile))[$fork_seqn];
@@ -527,39 +533,6 @@ sub count_of_failed_tests {
 }
 
 
-sub profile_this_code {
-    my %opt = @_;
-
-    my (undef, $out_file) = tempfile('nytprof_XXXXXX', SUFFIX => 'out');
-    
-    my @perl = ($perl, '-d:NYTProf');
-    push @perl, @{ $opt{perl_opts} } if $opt{perl_opts};
-
-    if (my $src_file = $opt{src_file}) {
-        system($perl, '-d:NYTProf', $src_file) == 0
-            or carp "@perl $src_file exited with an error status";
-    }
-    elsif (my $src_code = $opt{src_code}) {
-        open my $fh, '|-', @perl
-            or croak "Can't open pipe to @perl";
-        print $fh $src_code; 
-        close $fh
-            or carp "@perl exited with an error status";
-    }
-    else {
-        croak "Neither src_file or src_code was provided";
-    }
-    
-    my $profile = Devel::NYTProf::Data->new( {
-        filename => $out_file,
-        callback => $opts{for_chunks},
-    } );
-
-    unlink $out_file;
-
-    return $profile;
-}
-
 
 1;
 
